PasskeyAuthenticator

Struct PasskeyAuthenticator 

pub struct PasskeyAuthenticator { /* private fields */ }
A passkey authenticator.

BCS

The BCS serialized form for this type is defined by the following ABNF:

passkey-bcs = bytes               ; where the contents of the bytes are
                                  ; defined by <passkey>
passkey     = passkey-flag
              bytes               ; passkey authenticator data
              client-data-json    ; valid json
              simple-signature    ; required to be a secp256r1 signature

client-data-json = string ; valid json

See CollectedClientData for the required json-schema for the client-data-json rule. In addition, IOTA currently requires that the CollectedClientData.type field is required to be webauthn.get and that the CollectedClientData.challenge field decodes to exactly 32 bytes, the length of the signing digest it must match.

Note: Due to historical reasons, signatures are serialized slightly different from the majority of the types in IOTA. In particular if a signature is ever embedded in another structure it generally is serialized as bytes meaning it has a length prefix that defines the length of the completely serialized signature.

Implementations



impl PasskeyAuthenticator

pub fn public_key(&self) -> PasskeyPublicKey

The passkey public key.

pub fn signature(&self) -> SimpleSignature

The passkey signature.

pub fn challenge(&self) -> &[u8]

The parsed challenge message for this passkey signature.

This is parsed by decoding the base64url data from the client_data_json.challenge field, and is guaranteed to be exactly 32 bytes, the length of the signing digest it must match.

pub fn authenticator_data(&self) -> &[u8]

Opaque authenticator data for this passkey signature.

See Authenticator Data for more information on this field.

pub fn client_data_json(&self) -> &str

Structured, unparsed, JSON for this passkey signature.

See CollectedClientData for more information on this field.



impl PasskeyAuthenticator

pub fn new( authenticator_data: Vec<u8>, client_data_json: String, signature: SimpleSignature, ) -> Result<PasskeyAuthenticator, SignatureFromBytesError>

pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<PasskeyAuthenticator, SignatureFromBytesError>

pub fn to_bytes(&self) -> Vec<u8>